Struct demand::MultiSelect
source · pub struct MultiSelect<'a, T> {
pub title: String,
pub theme: &'a Theme,
pub description: String,
pub options: Vec<DemandOption<T>>,
pub min: usize,
pub max: usize,
pub filterable: bool,
/* private fields */
}Expand description
Select multiple options from a list
Example
use demand::{DemandOption, MultiSelect};
let multiselect = MultiSelect::new("Toppings")
.description("Select your toppings")
.min(1)
.max(4)
.filterable(true)
.option(DemandOption::new("Lettuce").selected(true))
.option(DemandOption::new("Tomatoes").selected(true))
.option(DemandOption::new("Charm Sauce"))
.option(DemandOption::new("Jalapenos").label("Jalapeños"))
.option(DemandOption::new("Cheese"))
.option(DemandOption::new("Vegan Cheese"))
.option(DemandOption::new("Nutella"));
let toppings = multiselect.run().expect("error running multi select");Fields
title: StringThe title of the selector
theme: &'a ThemeThe colors/style of the selector
description: StringA description to display above the selector
options: Vec<DemandOption<T>>The options which can be selected
min: usizeThe minimum number of options which must be selected
max: usizeThe maximum number of options which can be selected
filterable: boolWhether the selector can be filtered with a query
Implementations
sourceimpl<'a, T> MultiSelect<'a, T>
impl<'a, T> MultiSelect<'a, T>
sourcepub fn description(self, description: &str) -> Self
pub fn description(self, description: &str) -> Self
Set the description of the selector
sourcepub fn option(self, option: DemandOption<T>) -> Self
pub fn option(self, option: DemandOption<T>) -> Self
Add an option to the selector
sourcepub fn options(self, options: Vec<DemandOption<T>>) -> Self
pub fn options(self, options: Vec<DemandOption<T>>) -> Self
Add multiple options to the selector
sourcepub fn filterable(self, filterable: bool) -> Self
pub fn filterable(self, filterable: bool) -> Self
Set whether the selector can be filtered with a query