Struct demand::MultiSelect

source ·
pub struct MultiSelect<T: Display> {
    pub title: String,
    pub theme: Theme,
    pub description: String,
    pub options: Vec<DemandOption<T>>,
    pub min: usize,
    pub max: usize,
    pub filterable: bool,
    /* private fields */
}
Select multiple options from a list

Example

use demand::{DemandOption, MultiSelect};

let ms = MultiSelect::new("Toppings")
  .description("Select your toppings")
  .min(1)
  .max(4)
  .filterable(true)
  .option(DemandOption::new("Lettuce").selected(true))
  .option(DemandOption::new("Tomatoes").selected(true))
  .option(DemandOption::new("Charm Sauce"))
  .option(DemandOption::new("Jalapenos").label("Jalapeños"))
  .option(DemandOption::new("Cheese"))
  .option(DemandOption::new("Vegan Cheese"))
  .option(DemandOption::new("Nutella"));///
let toppings = ms.run().expect("error running multi select");

Fields

title: String

The title of the selector

theme: Theme

The colors/style of the selector

description: String

A description to display above the selector

options: Vec<DemandOption<T>>

The options which can be selected

min: usize

The minimum number of options which must be selected

max: usize

The maximum number of options which can be selected

filterable: bool

Whether the selector can be filtered with a query

Implementations

source

impl<T: Display> MultiSelect<T>

source

pub fn new<S: Into<String>>(title: S) -> Self

Create a new multi select with the given title

Examples found in repository?
examples/multiselect.rs (line 4)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
fn main() {
    let ms = MultiSelect::new("Toppings")
        .description("Select your toppings")
        .min(1)
        .max(4)
        .filterable(true)
        .option(DemandOption::new("Lettuce").selected(true))
        .option(DemandOption::new("Tomatoes").selected(true))
        .option(DemandOption::new("Charm Sauce"))
        .option(DemandOption::new("Jalapenos").label("Jalapeños"))
        .option(DemandOption::new("Cheese"))
        .option(DemandOption::new("Vegan Cheese"))
        .option(DemandOption::new("Nutella"));
    ms.run().expect("error running multi select");
}
source

pub fn description(self, description: &str) -> Self

Set the description of the selector

Examples found in repository?
examples/multiselect.rs (line 5)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
fn main() {
    let ms = MultiSelect::new("Toppings")
        .description("Select your toppings")
        .min(1)
        .max(4)
        .filterable(true)
        .option(DemandOption::new("Lettuce").selected(true))
        .option(DemandOption::new("Tomatoes").selected(true))
        .option(DemandOption::new("Charm Sauce"))
        .option(DemandOption::new("Jalapenos").label("Jalapeños"))
        .option(DemandOption::new("Cheese"))
        .option(DemandOption::new("Vegan Cheese"))
        .option(DemandOption::new("Nutella"));
    ms.run().expect("error running multi select");
}
source

pub fn option(self, option: DemandOption<T>) -> Self

Add an option to the selector

Examples found in repository?
examples/multiselect.rs (line 9)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
fn main() {
    let ms = MultiSelect::new("Toppings")
        .description("Select your toppings")
        .min(1)
        .max(4)
        .filterable(true)
        .option(DemandOption::new("Lettuce").selected(true))
        .option(DemandOption::new("Tomatoes").selected(true))
        .option(DemandOption::new("Charm Sauce"))
        .option(DemandOption::new("Jalapenos").label("Jalapeños"))
        .option(DemandOption::new("Cheese"))
        .option(DemandOption::new("Vegan Cheese"))
        .option(DemandOption::new("Nutella"));
    ms.run().expect("error running multi select");
}
source

pub fn min(self, min: usize) -> Self

Set the minimum number of options which must be selected

Examples found in repository?
examples/multiselect.rs (line 6)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
fn main() {
    let ms = MultiSelect::new("Toppings")
        .description("Select your toppings")
        .min(1)
        .max(4)
        .filterable(true)
        .option(DemandOption::new("Lettuce").selected(true))
        .option(DemandOption::new("Tomatoes").selected(true))
        .option(DemandOption::new("Charm Sauce"))
        .option(DemandOption::new("Jalapenos").label("Jalapeños"))
        .option(DemandOption::new("Cheese"))
        .option(DemandOption::new("Vegan Cheese"))
        .option(DemandOption::new("Nutella"));
    ms.run().expect("error running multi select");
}
source

pub fn max(self, max: usize) -> Self

Set the maximum number of options which can be selected

Examples found in repository?
examples/multiselect.rs (line 7)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
fn main() {
    let ms = MultiSelect::new("Toppings")
        .description("Select your toppings")
        .min(1)
        .max(4)
        .filterable(true)
        .option(DemandOption::new("Lettuce").selected(true))
        .option(DemandOption::new("Tomatoes").selected(true))
        .option(DemandOption::new("Charm Sauce"))
        .option(DemandOption::new("Jalapenos").label("Jalapeños"))
        .option(DemandOption::new("Cheese"))
        .option(DemandOption::new("Vegan Cheese"))
        .option(DemandOption::new("Nutella"));
    ms.run().expect("error running multi select");
}
source

pub fn filterable(self, filterable: bool) -> Self

Set whether the selector can be filtered with a query

Examples found in repository?
examples/multiselect.rs (line 8)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
fn main() {
    let ms = MultiSelect::new("Toppings")
        .description("Select your toppings")
        .min(1)
        .max(4)
        .filterable(true)
        .option(DemandOption::new("Lettuce").selected(true))
        .option(DemandOption::new("Tomatoes").selected(true))
        .option(DemandOption::new("Charm Sauce"))
        .option(DemandOption::new("Jalapenos").label("Jalapeños"))
        .option(DemandOption::new("Cheese"))
        .option(DemandOption::new("Vegan Cheese"))
        .option(DemandOption::new("Nutella"));
    ms.run().expect("error running multi select");
}
source

pub fn theme(self, theme: Theme) -> Self

Set the theme of the selector

source

pub fn run(self) -> Result<Vec<T>>

Displays the selector to the user and returns their selected options

Examples found in repository?
examples/multiselect.rs (line 16)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
fn main() {
    let ms = MultiSelect::new("Toppings")
        .description("Select your toppings")
        .min(1)
        .max(4)
        .filterable(true)
        .option(DemandOption::new("Lettuce").selected(true))
        .option(DemandOption::new("Tomatoes").selected(true))
        .option(DemandOption::new("Charm Sauce"))
        .option(DemandOption::new("Jalapenos").label("Jalapeños"))
        .option(DemandOption::new("Cheese"))
        .option(DemandOption::new("Vegan Cheese"))
        .option(DemandOption::new("Nutella"));
    ms.run().expect("error running multi select");
}