pub struct Wizard<'a, S> { /* private fields */ }Expand description
A multi-step wizard with clickable breadcrumb navigation
Example
ⓘ
use demand::{Wizard, Section, Navigation, Input};
#[derive(Default)]
struct State {
name: String,
email: String,
}
let result = Wizard::new("Setup")
.section("Name", |state: &mut State, theme| {
let name = Input::new("Your name")
.theme(theme)
.run()?;
state.name = name;
Ok(Navigation::Next)
})
.section("Email", |state: &mut State, theme| {
let email = Input::new("Your email")
.theme(theme)
.run()?;
state.email = email;
Ok(Navigation::Next)
})
.section("Done", |_state, _theme| {
Ok(Navigation::Done)
})
.run(&mut State::default())?;Implementations
Sourceimpl<'a, S> Wizard<'a, S>
impl<'a, S> Wizard<'a, S>
Sourcepub fn run(self, state: &mut S) -> Result<()>
pub fn run(self, state: &mut S) -> Result<()>
Run the wizard with the given state
Returns the final state when Navigation::Done is received.
Returns an error with io::ErrorKind::Interrupted if the user cancels.
Render the breadcrumb navigation bar as a string.
This method is available for consumers who want to display the breadcrumb
in custom UI layouts. Note that sections receive only (&mut S, &Theme)
and don’t have direct access to the Wizard instance.
Returns the rendered breadcrumb as a string that can be printed.